summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/kdevlang/kdevlang_part.cpp')
-rw-r--r--languages/cpp/app_templates/kdevlang/kdevlang_part.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp b/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp
index 9d5cadcf..364ec0d7 100644
--- a/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp
+++ b/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp
@@ -1,7 +1,7 @@
%{CPP_TEMPLATE}
-#include <qwhatsthis.h>
-#include <qtimer.h>
+#include <tqwhatsthis.h>
+#include <tqtimer.h>
#include <kiconloader.h>
#include <klocale.h>
@@ -21,24 +21,24 @@ typedef KGenericFactory<%{APPNAME}Part> %{APPNAME}Factory;
K_EXPORT_COMPONENT_FACTORY( libkdev%{APPNAMELC}, %{APPNAME}Factory( "kdev%{APPNAMELC}" ) );
static const KDevPluginInfo data("kdev%{APPNAMELC}");
%{APPNAME}Part::%{APPNAME}Part(QObject *parent, const char *name, const QStringList& )
: KDevLanguageSupport(&data, parent, name ? name : "%{APPNAME}Part" )
{
setInstance(%{APPNAME}Factory::instance());
setXMLFile("kdevlang_%{APPNAMELC}.rc");
- m_build = new KAction( i18n("&Run"), "exec",Key_F9,this, SLOT(slotRun()),actionCollection(), "build_execute" );
+ m_build = new KAction( i18n("&Run"), "exec",Key_F9,this, TQT_SLOT(slotRun()),actionCollection(), "build_execute" );
kdDebug() << "Creating %{APPNAMELC} Part" << endl;
- connect( core(), SIGNAL(projectConfigWidget(KDialogBase*)),
- this, SLOT(projectConfigWidget(KDialogBase*)) );
- connect( core(), SIGNAL(projectOpened()), this, SLOT(projectOpened()) );
- connect( core(), SIGNAL(projectClosed()), this, SLOT(projectClosed()) );
- connect( partController(), SIGNAL(savedFile(const KURL&)), this, SLOT(savedFile(const KURL&)) );
- connect(partController(), SIGNAL(activePartChanged(KParts::Part*)),
- this, SLOT(slotActivePartChanged(KParts::Part *)));
+ connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)),
+ this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
+ connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()) );
+ connect( core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()) );
+ connect( partController(), TQT_SIGNAL(savedFile(const KURL&)), this, TQT_SLOT(savedFile(const KURL&)) );
+ connect(partController(), TQT_SIGNAL(activePartChanged(KParts::Part*)),
+ this, TQT_SLOT(slotActivePartChanged(KParts::Part *)));
}
@@ -74,14 +74,14 @@ void %{APPNAME}Part::projectOpened()
{
kdDebug(9014) << "projectOpened()" << endl;
- connect( project(), SIGNAL(addedFilesToProject(const QStringList &)),
- this, SLOT(addedFilesToProject(const QStringList &)) );
- connect( project(), SIGNAL(removedFilesFromProject(const QStringList &)),
- this, SLOT(removedFilesFromProject(const QStringList &)) );
+ connect( project(), TQT_SIGNAL(addedFilesToProject(const TQStringList &)),
+ this, TQT_SLOT(addedFilesToProject(const TQStringList &)) );
+ connect( project(), TQT_SIGNAL(removedFilesFromProject(const TQStringList &)),
+ this, TQT_SLOT(removedFilesFromProject(const TQStringList &)) );
// We want to parse only after all components have been
// properly initialized
- QTimer::singleShot(0, this, SLOT(parse()));
+ TQTimer::singleShot(0, this, TQT_SLOT(parse()));
}
void %{APPNAME}Part::projectClosed()
{
@@ -97,11 +97,11 @@ void %{APPNAME}Part::savedFile(const KURL &fileName)
emit addedSourceInfo( fileName.path() );
}
}
-void %{APPNAME}Part::addedFilesToProject(const QStringList &fileList)
+void %{APPNAME}Part::addedFilesToProject(const TQStringList &fileList)
{
kdDebug(9014) << "addedFilesToProject()" << endl;
- QStringList::ConstIterator it;
+ TQStringList::ConstIterator it;
for ( it = fileList.begin(); it != fileList.end(); ++it )
{
@@ -110,15 +110,15 @@ void %{APPNAME}Part::addedFilesToProject(const QStringList &fileList)
emit updatedSourceInfo();
}
-void %{APPNAME}Part::removedFilesFromProject(const QStringList &fileList)
+void %{APPNAME}Part::removedFilesFromProject(const TQStringList &fileList)
{
- QStringList::ConstIterator it;
+ TQStringList::ConstIterator it;
for ( it = fileList.begin(); it != fileList.end(); ++it )
{
- QString fileName = project()->projectDirectory() + "/" + ( *it );
+ TQString fileName = project()->projectDirectory() + "/" + ( *it );
if( codeModel()->hasFile(fileName) )
{
kdDebug(9014) << "removed " << fileName << endl;
@@ -135,8 +135,8 @@ void %{APPNAME}Part::parse()
if (project())
{
kapp->setOverrideCursor(waitCursor);
- QStringList files = project()->allFiles();
- for (QStringList::Iterator it = files.begin(); it != files.end() ;++it)
+ TQStringList files = project()->allFiles();
+ for (TQStringList::Iterator it = files.begin(); it != files.end() ;++it)
{
kdDebug(9014) << "maybe parse " << project()->projectDirectory() + "/" + (*it) << endl;
}
@@ -21,24 +21,24 @@ typedef KGenericFactory<%{APPNAME}Part> %{APPNAME}Factory;
K_EXPORT_COMPONENT_FACTORY( libkdev%{APPNAMELC}, %{APPNAME}Factory( "kdev%{APPNAMELC}" ) );
static const KDevPluginInfo data("kdev%{APPNAMELC}");
-%{APPNAME}Part::%{APPNAME}Part(QObject *parent, const char *name, const QStringList& )
+%{APPNAME}Part::%{APPNAME}Part(TQObject *parent, const char *name, const TQStringList& )
: KDevLanguageSupport(&data, parent, name ? name : "%{APPNAME}Part" )
{